"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _getLog = _interopRequireDefault(require("./get-log"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const connect = async (pool, specific) => {
  const log = (0, _getLog.default)('connect');
  log.debug('configuring postgres client');
  const {
    Postgres,
    escapeId,
    escape,
    fullJitter,
    executeStatement,
    coercer
  } = specific;
  let {
    databaseName,
    eventsTableName,
    snapshotsTableName,
    secretsTableName,
    // eslint-disable-next-line prefer-const
    ...connectionOptions
  } = pool.config;
  eventsTableName = pool.coerceEmptyString(eventsTableName, 'events');
  snapshotsTableName = pool.coerceEmptyString(snapshotsTableName, 'snapshots');
  secretsTableName = pool.coerceEmptyString(secretsTableName, 'default');
  databaseName = pool.coerceEmptyString(databaseName);
  Object.assign(pool, {
    databaseName,
    eventsTableName,
    snapshotsTableName,
    secretsTableName,
    connectionOptions,
    Postgres,
    fullJitter,
    coercer,
    executeStatement: executeStatement.bind(null, pool),
    escapeId,
    escape
  });

  if (pool.executeStatement != null) {
    await pool.executeStatement('SELECT 0 AS "defunct"');
  }

  log.debug('connection to postgres databases established');
};

var _default = connect;
exports.default = _default;
//# sourceMappingURL=connect.js.map